@@ -152,12 +152,12 @@ var loadEvent = function() {
 	body.insertBefore(link, body.firstChild);
 	var html = [
 	'<div class="bubble">',
-	    '<iframe src="/bags/common/tiddlers/backstage" width="auto" style="border:none;"></iframe>',
+	    '<iframe src="/bags/common/tiddlers/backstage#userpass-login" width="auto" style="border:none;"></iframe>',
 	    '<div class="tail"></div>',
 	'</div>'].join("");
 	var bubble = document.createElement("div");
 	bubble.setAttribute("id", "bs-popup");
-	bubble.style.cssText = "display:none;";
+	bubble.style.cssText = "visibility:hidden;";
 	bubble.className = "bs-popup";
 	bubble.innerHTML = html;
 	body.insertBefore(bubble, link);
@@ -176,7 +176,7 @@ var loadEvent = function() {
 			opacity = fadeIn ? opacity + 0.1 : opacity - 0.1;
 			if(opacity < 0 || opacity > 1) {
 				clearInterval(bubbleFadeInterval);
-				el.style.cssText = fadeIn ? "" : "display:none;";
+				el.style.cssText = fadeIn ? "" : "visibility:hidden;";
 			}
 		}, 50);
 	}
